@@ -1,3 +1,4 @@
+# pylint: disable=C0103
 """
 Aggregate and grouping results:
 https://docs.microsoft.com/en-us/powerapps/developer/data-platform/webapi/query-data-web-api#aggregate-and-grouping-results
@@ -6,15 +7,13 @@ FetchXML aggregation documentation:
 https://docs.microsoft.com/en-us/powerapps/developer/data-platform/use-fetchxml-aggregation
 """
 
-from typing import List, Literal, Set, Union
+from .typing import FilterType, List, Literal
 
 
 __all__ = ["apl"]
 
-filter_type = Union[Set[str], List[str]]
 
-
-class APL:
+class apl:
     """Convenience functions for creating $apply parameters."""
 
     @staticmethod
@@ -38,20 +37,17 @@ class APL:
         return f"aggregate({col_} with {with_} as {as_})"
 
     @staticmethod
-    def filter(by: filter_type, group_by_columns: List[str]):
+    def filter(by: FilterType, group_by_columns: List[str]) -> str:
         """Group filtered values by columns.
 
         :param by: Filter results by this filter string before applying grouping. Use `ftr` to construct this.
         :param group_by_columns: Columns to group by.
         """
-        return f"filter({APL._compile_filter(by).removeprefix('$filter=')})/" + APL.groupby(group_by_columns)
+        if isinstance(by, set):
+            filters = " or ".join([value.strip() for value in by])
+        elif isinstance(by, list):
+            filters = " and ".join([value.strip() for value in by])
+        else:
+            raise TypeError("Filter by must be either a set or a list.")
 
-    @staticmethod
-    def _compile_filter(values: filter_type):
-        if isinstance(values, set):
-            return "$filter=" + " or ".join([value.strip() for value in values])
-        elif isinstance(values, list):
-            return "$filter=" + " and ".join([value.strip() for value in values])
-
-
-apl = APL()
+        return f"filter({filters})/" + apl.groupby(group_by_columns)
