@@ -10,10 +10,9 @@ Date: April 5th, 2021.
 import json
 import logging
 import os
-from concurrent.futures import ThreadPoolExecutor
-from functools import wraps
+from urllib.parse import quote
 
-from oauthlib.oauth2 import BackendApplicationClient, OAuth2Token
+from oauthlib.oauth2 import BackendApplicationClient
 from requests_oauthlib import OAuth2Session
 
 from . import status
@@ -45,15 +44,7 @@ from .typing import (
     OrderbyType,
     Type,
 )
-from .utils import sentinel
-
-
-try:
-    from django.core.cache import cache
-except ImportError:
-    from .utils import SQLiteCache
-
-    cache = SQLiteCache()
+from .utils import error_simplification_available, get_token, sentinel, set_token
 
 
 __all__ = ["DynamicsClient"]
@@ -62,58 +53,6 @@ __all__ = ["DynamicsClient"]
 logger = logging.getLogger(__name__)
 
 
-def get_token() -> OAuth2Token:
-    """Get dynamics client token in a thread, so it can be done in an async context."""
-
-    def task() -> OAuth2Token:
-        return cache.get("dynamics-client-token", None)
-
-    with ThreadPoolExecutor() as executor:
-        future = executor.submit(task)
-        return future.result()
-
-
-def set_token(token: OAuth2Token):
-    """Set dynamics client token in a thread, so it can be done in an async context."""
-
-    def task():
-        name = "dynamics-client-token"
-        expires = int(token["expires_in"]) - 60
-        cache.set(name, token, expires)
-
-    with ThreadPoolExecutor() as executor:
-        future = executor.submit(task)
-        return future.result()
-
-
-def error_simplification_available(func):
-    """Errors in the function decorated with this decorator can be simplified to just a
-    DynamicsException with default error message using the keyword: 'simplify_errors'.
-    This is useful if you want to hide error details from frontend users.
-
-    You can use the 'raise_separately' keyword to list exception types to exclude from this
-    simplification, if separate handling is needed.
-
-    :param func: Decorated function.
-    """
-
-    @wraps(func)
-    def inner(*args, **kwargs):
-        simplify_errors: bool = kwargs.pop("simplify_errors", False)
-        raise_separately: List[Type[Exception]] = kwargs.pop("raise_separately", [])
-
-        try:
-            return func(*args, **kwargs)
-        except Exception as error:  # pylint: disable=W0703
-            logger.warning(error)
-            if not simplify_errors or any(isinstance(error, exception) for exception in raise_separately):
-                raise error
-            self: "DynamicsClient" = args[0]
-            raise DynamicsException(self.simplified_error_message) from error
-
-    return inner
-
-
 class DynamicsClient:  # pylint: disable=R0904,R0902
     """Dynamics client for making queries from a Microsoft Dynamics 365 database."""
 
@@ -153,7 +92,7 @@ class DynamicsClient:  # pylint: disable=R0904,R0902
         self._api_url = api_url.rstrip("/") + "/"
         self._session = OAuth2Session(client=BackendApplicationClient(client_id=client_id))
         token = get_token()
-        if token is None:
+        if token is None:  # pragma: no cover
             token = self._session.fetch_token(token_url=token_url, client_secret=client_secret, scope=scope)
             set_token(token)
         else:
@@ -177,6 +116,7 @@ class DynamicsClient:  # pylint: disable=R0904,R0902
         self._add_ref_to_property = ""
         self._pre_expand = ""
         self._apply = ""
+        self._fetch_xml = ""
 
         self._headers: Dict[str, str] = {}
         self._pagesize: int = 5000
@@ -239,6 +179,7 @@ class DynamicsClient:  # pylint: disable=R0904,R0902
             [
                 statement
                 for statement in [
+                    self._compile_fetch_xml(),
                     self._compile_expand(),
                     self._compile_apply(),
                     self._compile_select(),
@@ -273,6 +214,7 @@ class DynamicsClient:  # pylint: disable=R0904,R0902
         self._add_ref_to_property = ""
         self._pre_expand = ""
         self._apply = ""
+        self._fetch_xml = ""
 
         self._headers: Dict[str, str] = {}
 
@@ -812,8 +754,33 @@ class DynamicsClient:  # pylint: disable=R0904,R0902
 
         self._pagesize = value
 
-    # TODO: fetchXml:
-    #  https://docs.microsoft.com/en-us/powerapps/developer/data-platform/
-    #   use-fetchxml-construct-query
-    #  https://docs.microsoft.com/en-us/powerapps/developer/data-platform/
-    #   webapi/retrieve-and-execute-predefined-queries#use-custom-fetchxml
+    @property
+    def fetch_xml(self) -> str:
+        """Get current FetchXML query string."""
+
+        return self._fetch_xml
+
+    @fetch_xml.setter
+    def fetch_xml(self, value: str) -> None:
+        """Set a query using the FetchXML query language.
+        Must set table, but cannot set any other query options!
+
+        Queries can be constructed with the included FetchXMLBuilder.
+
+        XML Shema:
+        https://docs.microsoft.com/en-us/powerapps/developer/data-platform/fetchxml-schema
+
+        How to use:
+        https://docs.microsoft.com/en-us/powerapps/developer/data-platform/use-fetchxml-construct-query
+        """
+
+        self._fetch_xml = value
+
+    def _compile_fetch_xml(self, value: str = sentinel) -> str:
+        if value is sentinel:
+            value = self._fetch_xml
+
+        return "fetchXml=" + quote(value, safe="") if value else ""
+
+    # TODO: Batch requests
+    #  https://docs.microsoft.com/en-us/powerapps/developer/data-platform/webapi/execute-batch-operations-using-web-api
